==> haskell-uuid-types-1.0.2-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-uuid-types/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid-types
version: 1.0.2
id: uuid-types-1.0.2-cc5f0dab6e27ccfe55a1db8d7f961e13
key: uuidt_6aItOBOuV3WGsQ2J52Ow92
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal.Builder
    Data.UUID.Types.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-types-1.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-types-1.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/uuid-types-1.0.2
hs-libraries: HSuuid-types-1.0.2-6aItOBOuV3WGsQ2J52Ow92
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-44b2533f61c94bc76cb2b27e15566721
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html: /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-types-1.0.2-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-uuid-types/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid-types
version: 1.0.2
id: uuid-types-1.0.2-e80dd8ed3b7ffef1dd40876281d96804
key: uuidt_Kbofz3yQbJYIj1DO4WUJlu
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: Type definitions for Universally Unique Identifiers
description:
    This library contains type definitions for Universally Unique Identifiers
    and basic conversion functions.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID.Types Data.UUID.Types.Internal.Builder
    Data.UUID.Types.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-types-1.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-types-1.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/uuid-types-1.0.2
hs-libraries: HSuuid-types-1.0.2-Kbofz3yQbJYIj1DO4WUJlu
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
haddock-interfaces: /usr/share/doc/haskell-uuid-types/html/uuid-types.haddock
haddock-html: /usr/share/doc/haskell-uuid-types/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
